==> kubernetes-model-policy-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/SELinuxStrategyOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.SELinuxOptions;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class SELinuxStrategyOptionsFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1beta1.SELinuxStrategyOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1beta1.SELinuxStrategyOptionsFluent<A>{
  public SELinuxStrategyOptionsFluentImpl() {
  }
  public SELinuxStrategyOptionsFluentImpl(io.fabric8.kubernetes.api.model.policy.v1beta1.SELinuxStrategyOptions instance) {
    this.withRule(instance.getRule()); 
    this.withSeLinuxOptions(instance.getSeLinuxOptions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String rule;
  private io.fabric8.kubernetes.api.model.SELinuxOptions seLinuxOptions;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getRule() {
    return this.rule;
  }
  public A withRule(java.lang.String rule) {
    this.rule=rule; return (A) this;
  }
  public java.lang.Boolean hasRule() {
    return this.rule != null;
  }
  
  /**
   * Method is deprecated. use withRule instead.
   */
  @java.lang.Deprecated
  public A withNewRule(java.lang.String arg0) {
    return (A)withRule(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SELinuxOptions getSeLinuxOptions() {
    return this.seLinuxOptions;
  }
  public A withSeLinuxOptions(io.fabric8.kubernetes.api.model.SELinuxOptions seLinuxOptions) {
    this.seLinuxOptions=seLinuxOptions; return (A) this;
  }
  public java.lang.Boolean hasSeLinuxOptions() {
    return this.seLinuxOptions != null;
  }
  public A withNewSeLinuxOptions(java.lang.String level,java.lang.String role,java.lang.String type,java.lang.String user) {
    return (A)withSeLinuxOptions(new SELinuxOptions(level, role, type, user));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SELinuxStrategyOptionsFluentImpl that = (SELinuxStrategyOptionsFluentImpl) o;
    if (rule != null ? !rule.equals(that.rule) :that.rule != null) return false;
    if (seLinuxOptions != null ? !seLinuxOptions.equals(that.seLinuxOptions) :that.seLinuxOptions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rule,  seLinuxOptions,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-policy-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/SELinuxStrategyOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.SELinuxOptions;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class SELinuxStrategyOptionsFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1beta1.SELinuxStrategyOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1beta1.SELinuxStrategyOptionsFluent<A>{
  public SELinuxStrategyOptionsFluentImpl() {
  }
  public SELinuxStrategyOptionsFluentImpl(io.fabric8.kubernetes.api.model.policy.v1beta1.SELinuxStrategyOptions instance) {
    this.withRule(instance.getRule()); 
    this.withSeLinuxOptions(instance.getSeLinuxOptions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String rule;
  private io.fabric8.kubernetes.api.model.SELinuxOptions seLinuxOptions;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getRule() {
    return this.rule;
  }
  public A withRule(java.lang.String rule) {
    this.rule=rule; return (A) this;
  }
  public java.lang.Boolean hasRule() {
    return this.rule != null;
  }
  
  /**
   * Method is deprecated. use withRule instead.
   */
  @java.lang.Deprecated
  public A withNewRule(java.lang.String arg0) {
    return (A)withRule(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SELinuxOptions getSeLinuxOptions() {
    return this.seLinuxOptions;
  }
  public A withSeLinuxOptions(io.fabric8.kubernetes.api.model.SELinuxOptions seLinuxOptions) {
    this.seLinuxOptions=seLinuxOptions; return (A) this;
  }
  public java.lang.Boolean hasSeLinuxOptions() {
    return this.seLinuxOptions != null;
  }
  public A withNewSeLinuxOptions(java.lang.String level,java.lang.String role,java.lang.String type,java.lang.String user) {
    return (A)withSeLinuxOptions(new SELinuxOptions(level, role, type, user));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SELinuxStrategyOptionsFluentImpl that = (SELinuxStrategyOptionsFluentImpl) o;
    if (rule != null ? !rule.equals(that.rule) :that.rule != null) return false;
    if (seLinuxOptions != null ? !seLinuxOptions.equals(that.seLinuxOptions) :that.seLinuxOptions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rule,  seLinuxOptions,  additionalProperties,  super.hashCode());
  }
  
}
